==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebFloatPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebFloatPaneActionDescription } from "./WebFloatPaneActionDescription";
/**
 * @hidden
 */
export let WebFloatPaneActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatPaneActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatPaneActionDescriptionMetadata.a == null) {
                WebFloatPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatPaneActionDescriptionMetadata.c(WebFloatPaneActionDescriptionMetadata.a);
            }
            if (a.j(WebFloatPaneActionDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFloatPaneActionDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebPaneDragActionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FloatPaneAction");
            a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
            a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
            a.item("Location", "ExportedType:WebDockManagerPoint");
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            WebFloatPaneActionDescriptionMetadata.b(a);
            a.aa("WebFloatPaneAction", () => new WebFloatPaneActionDescription());
            a.z("WebFloatPaneAction", WebFloatPaneActionDescriptionMetadata.a);
        }
    }
    WebFloatPaneActionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatPaneActionDescriptionMetadata, 'WebFloatPaneActionDescriptionMetadata');
    WebFloatPaneActionDescriptionMetadata.a = null;
    return WebFloatPaneActionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebFloatPaneActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebFloatPaneActionDescription } from "./WebFloatPaneActionDescription";
/**
 * @hidden
 */
export let WebFloatPaneActionDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatPaneActionDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatPaneActionDescriptionMetadata.a == null) {
                WebFloatPaneActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatPaneActionDescriptionMetadata.c(WebFloatPaneActionDescriptionMetadata.a);
            }
            if (a.k(WebFloatPaneActionDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFloatPaneActionDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebPaneDragActionDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:FloatPaneAction");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("ActionType", "(wc:Type)ExportedType:string:PaneDragActionType");
            a.item("ActionType@names", "FloatPane;MoveFloatingPane;DockPane;MoveTab");
            a.item("Location", "ExportedType:WebDockManagerPoint");
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            WebFloatPaneActionDescriptionMetadata.b(a);
            a.ac("WebFloatPaneAction", () => new WebFloatPaneActionDescription());
            a.ab("WebFloatPaneAction", WebFloatPaneActionDescriptionMetadata.a);
        }
    }
    WebFloatPaneActionDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatPaneActionDescriptionMetadata, 'WebFloatPaneActionDescriptionMetadata');
    WebFloatPaneActionDescriptionMetadata.a = null;
    return WebFloatPaneActionDescriptionMetadata;
})();
